@@ -112,15 +112,9 @@ static void pe_io_alarm(pe_watcher *_wa, pe_timeable *hit) {
 }
 
 static void _io_restart(pe_watcher *ev) {
-    char *excuse;
     if (!WaPOLLING(ev)) return;
     pe_watcher_off(ev);
-    excuse = pe_watcher_on(ev, 0);
-    if (SvIV(DebugLevel) && excuse) {
-	STRLEN n_a;
-	warn("Event: can't restart '%s' %s",
-	     SvPV(ev->desc, n_a), excuse);
-    }
+    pe_watcher_on(ev, 0);
 }
 
 static void pe_io_reset_handle(pe_watcher *ev) {  /* used by unix_io */
